PDF2EBook
=========

Convert pdfs to an epub


Dependencies
------------

Poppler - `sudo apt install libpoppler-cpp-dev`

PDFToHTML - `sudo apt install pdftohtml`


Installation
------------

`pip install pdf2ebook`


Usage
-----

`pdf2epub --in something.pdf --out other.epub`
